# -*- coding: utf-8 -*-
'''PyGame driver.'''

import pygame
import logging

from tuikit.driver import Driver
from tuikit.common import Size


class DriverPygame(Driver):
    
    '''PyGame driver class.'''
    
    key_map = {
        pygame.K_ESCAPE     : 'escape', 
        }
    
    color_map = {
        'black'   : (0,0,0),
        'blue'    : (0,0,0),
        'cyan'    : (0,0,0),
        'green'   : (0,0,0),
        'magenta' : (0,0,0),
        'red'     : (0,0,0),
        'white'   : (0,0,0),
        'yellow'  : (0,0,0),
        }
    
    def __init__(self):
        '''Initialize instance attributes'''
        Driver.__init__(self)
        self.log = logging.getLogger('tuikit')
        self.screen = None
        self.size.w, self.size.h = 80, 25  # screen size in characters
        self.charsize = Size(8, 16)  # character size in pixels

    def start(self, mainfunc):
        pygame.init()
        mode = self.size.w * self.charsize.w, self.size.h * self.charsize.h
        self.screen = pygame.display.set_mode(mode)
        mainfunc()


    ## input ##
    
    def getevents(self, timeout=None):
        '''Process input, return list of events.'''
        events = []
        for ev in pygame.event.get():
            if ev.type == pygame.MOUSEMOTION:
                pass
            elif ev.type == pygame.MOUSEBUTTONUP:
                pass
            elif ev.type == pygame.MOUSEBUTTONDOWN:
                pass
            elif ev.type == pygame.KEYDOWN:
                if ev.unicode:
                    events.append(('keypress', None, ev.unicode))
                elif ev.key in self.key_map:
                    events.append(('keypress', self.key_map[ev.key], None))
            elif ev.type == pygame.VIDEORESIZE:
                #self.size.h, self.size.w = self.screen.getmaxyx()
                events.append(('resize',))
            elif ev.type == pygame.QUIT:
                events.append(('quit',))
            else:
                self.log.warning('Unknown PyGame event: %r', ev.type)
        return events


    ## drawing ##
    
    def erase(self):
        '''Clear screen.'''
        self.screen.fill(self.color_map['black'])
    
    def putch(self, x, y, c):
        if not self.clipstack.test(x, y):
            return
#        try:
#            if isinstance(c, str) and len(c) == 1:
#                self.screen.addstr(y, x, c)
#            else:
#                self.screen.addch(y, x, c)
#        except curses.error:
#            pass

    def commit(self):
        '''Commit changes to the screen.'''
        pygame.display.flip()


    ## colors ##
    
    def setcolor(self, name, desc):
        '''Define color name.
        
        name - name of color (e.g. 'normal', 'active')
        desc - color description - foreground, background, attributes (e.g. 'black on white, bold')
        
        '''

    def pushcolor(self, name):
        '''Add color on top of stack and use this color for following output.'''
    
    def popcolor(self):
        '''Remove color from top of stack and use new top color for following output.'''


    ## cursor ##

    def showcursor(self, x, y):
        '''Set cursor to be shown at x, y coordinates.'''

    def hidecursor(self):
        '''Hide cursor.'''

